#!/usr/bin/env python

# Distributed under the terms of the BSD 3-Clause License.
# The full license is in the file LICENSE, distributed with this software.
#
# Author: Philipp Schmidt <philipp.schmidt@xfel.eu>
# Copyright (c) 2020, European X-Ray Free-Electron Laser Facility GmbH.
# All rights reserved.

from pathlib import Path

import numpy as np  # noqa
from Cython.Build import cythonize  # noqa

from setuptools import setup, find_packages
from setuptools.extension import Extension  # noqa


parent_path = Path(__file__).parent

setup(
    name='exdf-tools',
    version='1.0.0',
    description='Libraries and tools to work with the EXDF HDF5 tools.',
    long_description=(parent_path / 'README.md').read_text(),
    long_description_content_type='text/markdown',
    url='',
    author='European XFEL',
    author_email='da@xfel.eu',
    license='BSD-3-Clause',

    package_dir={'': 'src'},
    packages=find_packages('src'),

    entry_points={
        'console_scripts': [
            'exdf-glance = exdf.cli.glance:main',
            'exdf-reduce = exdf.cli.reduce:main',
            'exdf-compare = exdf.cli.compare:main'
        ],

        'exdf.data_reduction.method': [
            'ManualRemoval = exdf.data_reduction.builtins:ManualRemoval',
            'PurgeEmptySources = exdf.data_reduction.builtins:PurgeEmptySources',  # noqa
            'PpuTrainSequences = exdf.data_reduction.builtins:PpuTrainSequences',  # noqa
            'AgipdGain = exdf.data_reduction.builtins:AgipdGain',
            'LpdMini = exdf.data_reduction.builtins:LpdMini',
            'LitFrames = exdf.data_reduction.builtins:LitFrames',
        ]
    },

    python_requires='>=3.8',
    install_requires=[
        'extra_data>=1.13',
        'extra-redu',
        'pasha',

        # These are pulled in by EXtra-data but listed here for
        # completeness until they may require pinning.
        'packaging',
        'h5py',
    ],
    extras_require={
        'glance': ['uniplot'],
        'test': ['pytest'],
    },

    classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: BSD License',
          'Operating System :: POSIX :: Linux',
          'Topic :: Scientific/Engineering :: Information Analysis',
          'Topic :: Scientific/Engineering :: Physics',
    ]
)
