"""Glance at HDF5 files structured in the European XFEL Data Format (EXDF).
"""

from pathlib import Path
from argparse import ArgumentParser

import extra_data as xd


def main(argv=None):
    ap = ArgumentParser(
        description='Glance at HDF5 files structured in the European XFEL '
                    'Data Format (EXDF).'
    )

    ap.add_argument('paths', metavar='PATHS', type=Path, nargs='+',
                    help='files/folders to include in the data to look at.')

    data_group = ap.add_argument_group(
        'data options',
        'Allows to select the data to glance at.'
    ).add_mutually_exclusive_group()

    data_group.add_argument('--metadata', '-m', action='store_true')
    data_group.add_argument('--source', '-src', action='store', type=str)
    data_group.add_argument('--key', '-k', action='store', type=str,
                            help='<source>.<key>')

    reduce_group = ap.add_argument_group(
        'data reduction options',
        'Allow to specify data reduction before display.'
    )
    reduce_group.add_argument('--slice', '-s', metavar='SLICE_EXPR', type=str)
    reduce_group.add_argument('--mean', action='store', type=int, default=0)

    plot_group = ap.add_argument_group(
        'plot options',
        'Allows to control the way data is plotted.'
    )

    plot_group

    args = ap.parse_args(argv)

    paths = []

    for path in args.paths:
        if path.is_dir():
            paths += list(path.glob('*.h5'))
        elif path.is_file():
            paths.append(path)

    # TODO: is_single_run
    dc = xd.DataCollection.from_paths(paths, is_single_run=True)

    if args.metadata:
        print(dc.run_metadata())
        # print metadata
        pass
    elif args.source:
        # Plot
        dc.select(args.source).info(details_for_sources=[args.source])
    elif args.key:
        from uniplot import plot

        source, key = args.key.split(',')

        data = dc[source, key].ndarray()

        # TODO: slice expression

        plot(data)
    else:
        dc.info()

    '''
    if not args.filter:
        run.info()
    '''


if __name__ == '__main__':
    main()
